==> librejs-4.7.1.tar.gz: librejs-4.7.1/lib/html_script_finder/dom_handler/request.js <==
/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 */

var timer = require("timers");

var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
var {XPCOMUtils} = Cu.import("resource://gre/modules/XPCOMUtils.jsm");
var {NetUtil} = Cu.import("resource://gre/modules/NetUtil.jsm");

var converter = Cc["@mozilla.org/intl/scriptableunicodeconverter"].  
                createInstance(Ci.nsIScriptableUnicodeConverter);  

converter.charset = "UTF-8";


// ensure xhr won't create an infinite loop
// with html content.
var urlTester = require("html_script_finder/url_seen_tester").urlSeenTester;
var urlHandler = require("url_handler/url_handler");

var request = {
    
    url: null,

    channel: null,

    script: null,
    
    responseCallback: null,
    
    /**
     * init
     */
    init: function (script, callback) {

	this.script = script;

	// set initial url
	this.url = this.script.url;
	
	this.responseCallback = callback;

	var iOService = Cc["@mozilla.org/network/io-service;1"]
            .getService(Ci.nsIIOService);	

	this.channel = iOService.newChannel(this.url, null, null);


    },

    request: function () {

	var that = this;

	var responseReceived = function (data) {
	    that.responseCallback(that.script, data);
	};
	
	this.channel.asyncOpen({
				   QueryInterface: XPCOMUtils.generateQI([Ci.nsIRequestObserver, Ci.nsIStreamListener]),
				   
				   data: "",

				   onStartRequest: function(request, context) {},

				   onDataAvailable: function (request, context, stream, offset, count) {
				      this.data += NetUtil.readInputStreamToString(stream, count);
				   },

				   onStopRequest: function (request, context, result) {
				       try {
					   responseReceived(converter.ConvertToUnicode(this.data));					   
				       } catch (x) {
					   responseReceived(this.data);
				       }

				   }
				   
			       }, null);

    }


};

exports.request = function (script, callback) {
    var obj = Object.create(request);
    obj.init(script, callback);
    return obj;
};

==> librejs-4.8.tar.gz: librejs-4.8/lib/html_script_finder/dom_handler/request.js <==
/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 */

var timer = require("timers");

var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
var {XPCOMUtils} = Cu.import("resource://gre/modules/XPCOMUtils.jsm");





// ensure xhr won't create an infinite loop
// with html content.
var urlTester = require("html_script_finder/url_seen_tester").urlSeenTester;
var urlHandler = require("url_handler/url_handler");

var request = {
    
    url: null,

    channel: null,

    script: null,
    
    responseCallback: null,
    
    /**
     * init
     */
    init: function (script, callback) {

	this.script = script;

	// set initial url
	this.url = this.script.url;
	
	this.responseCallback = callback;

	var iOService = Cc["@mozilla.org/network/io-service;1"]
            .getService(Ci.nsIIOService);	

	this.channel = iOService.newChannel(this.url, null, null);


    },

    request: function () {

	var that = this;
	
	
	
	var responseReceived = function (data) {
	    that.responseCallback(that.script, data);
	};
	
	this.channel.asyncOpen({
				   QueryInterface: XPCOMUtils.generateQI([Ci.nsIRequestObserver, Ci.nsIStreamListener]),
				   
				   data: "",

				   onStartRequest: function(request, context) {},

				   onDataAvailable: function (request, context, stream, offset, count) {
				       try {	

					   // new solution used to prevent encoding bug with js files. 
					   // Some strings did not match the corresponding hashes for it.
					   var converterInputStream = Cc["@mozilla.org/intl/converter-input-stream;1"]
					       .createInstance(Ci.nsIConverterInputStream);
					   var data = {};
					   converterInputStream.init(stream, "UTF-8", count, ""); 

					   converterInputStream.readString(count, data);
					   
					   this.data += data.value;


				       } catch (x) {
					   console.log('error in request', x, x.lineNumber);
				       }

				   },

				   onStopRequest: function (request, context, result) {
				       try {
					   responseReceived(converter.ConvertToUnicode(this.data));					   
				       } catch (x) {
					   responseReceived(this.data);
				       }

				   }
				   
			       }, null);

    }


};

exports.request = function (script, callback) {
    var obj = Object.create(request);
    obj.init(script, callback);
    return obj;
};
